interface ShippoConfiguration {
    /**
     * ShippoConfiguration ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /** @readonly */
    revision?: string | null;
    /**
     * Date and time the ShippoConfiguration was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the ShippoConfiguration was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Associated delivery region ID.
     * @format GUID
     * @immutable
     * @deprecated Associated delivery region ID.
     * @replacedBy delivery_region_ids
     * @targetRemovalDate 2025-06-01
     */
    deliveryRegionId?: string | null;
    /**
     * Settings of USPS domestic services.
     * @maxSize 3
     */
    domesticServices?: DomesticServiceSettings[];
    /**
     * Settings of USPS international services.
     * @maxSize 3
     */
    internationalServices?: InternationalServiceSettings[];
    /** Package type. */
    packageType?: PackageTypeWithLiterals;
    /** Package details. */
    packageDetails?: PackageDetails;
    /**
     * Location ID from OS location service.
     * @format GUID
     */
    osLocationId?: string | null;
    /**
     * Ship from address materialized from OS location.
     * @readonly
     */
    shipFromAddress?: Address;
    /**
     * This shippo configuration is active for the following delivery regions.
     * @maxSize 50
     * @format GUID
     * @immutable
     */
    deliveryRegionIds?: string[];
    /**
     * Backup weight.
     * @decimalValue options { gte:0, maxScale:5 }
     */
    backupWeight?: string | null;
    /** Data extensions. */
    extendedFields?: ExtendedFields;
}
interface DomesticServiceSettings {
    /**
     * DomesticServiceSettings ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /** USPS domestic service. */
    service?: DomesticServiceWithLiterals;
    /** Service settings. */
    serviceSettings?: ServiceSettings;
}
declare enum DomesticService {
    UNKNOWN_DOMESTIC_SERVICE = "UNKNOWN_DOMESTIC_SERVICE",
    GROUND_ADVANTAGE = "GROUND_ADVANTAGE",
    PRIORITY_MAIL = "PRIORITY_MAIL",
    PRIORITY_MAIL_EXPRESS = "PRIORITY_MAIL_EXPRESS"
}
/** @enumType */
type DomesticServiceWithLiterals = DomesticService | 'UNKNOWN_DOMESTIC_SERVICE' | 'GROUND_ADVANTAGE' | 'PRIORITY_MAIL' | 'PRIORITY_MAIL_EXPRESS';
interface ServiceSettings {
    /**
     * Estimated delivery time.
     * @maxLength 500
     */
    estimatedDeliveryTime?: string | null;
    /** Handling fee. */
    handlingFee?: HandlingFee;
    /**
     * Amount above which free delivery is offered.
     * @decimalValue options { gte:0, maxScale:6 }
     */
    freeDeliveryMinimumAmount?: string | null;
}
interface HandlingFee {
    /**
     * Value that will be used to calculate the fee. For example, percentage fee with value 5% to calculate the fee.
     * @decimalValue options { gte:0, maxScale:4 }
     */
    value?: string;
    /** How to calculate the fee: fixed amount or by percentage. */
    calculationType?: CalculationTypeWithLiterals;
}
declare enum CalculationType {
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    FIXED = "FIXED",
    PERCENTAGE = "PERCENTAGE"
}
/** @enumType */
type CalculationTypeWithLiterals = CalculationType | 'UNKNOWN_TYPE' | 'FIXED' | 'PERCENTAGE';
interface InternationalServiceSettings {
    /**
     * InternationalServiceSettings ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /** USPS international service. */
    service?: InternationalServiceWithLiterals;
    /** Service settings. */
    serviceSettings?: ServiceSettings;
}
declare enum InternationalService {
    UNKNOWN_INTERNATIONAL_SERVICE = "UNKNOWN_INTERNATIONAL_SERVICE",
    FIRST_CLASS_PACKAGE_INTERNATIONAL = "FIRST_CLASS_PACKAGE_INTERNATIONAL",
    PRIORITY_MAIL_INTERNATIONAL = "PRIORITY_MAIL_INTERNATIONAL",
    PRIORITY_MAIL_EXPRESS_INTERNATIONAL = "PRIORITY_MAIL_EXPRESS_INTERNATIONAL"
}
/** @enumType */
type InternationalServiceWithLiterals = InternationalService | 'UNKNOWN_INTERNATIONAL_SERVICE' | 'FIRST_CLASS_PACKAGE_INTERNATIONAL' | 'PRIORITY_MAIL_INTERNATIONAL' | 'PRIORITY_MAIL_EXPRESS_INTERNATIONAL';
declare enum PackageType {
    UNKNOWN_PACKAGE_TYPE = "UNKNOWN_PACKAGE_TYPE",
    CUSTOM = "CUSTOM",
    FLAT_RATE_ENVELOPE = "FLAT_RATE_ENVELOPE",
    PADDED_FLAT_RATE_ENVELOPE = "PADDED_FLAT_RATE_ENVELOPE",
    SMALL_FLAT_RATE_BOX = "SMALL_FLAT_RATE_BOX",
    MEDIUM_FLAT_RATE_BOX_1 = "MEDIUM_FLAT_RATE_BOX_1",
    MEDIUM_FLAT_RATE_BOX_2 = "MEDIUM_FLAT_RATE_BOX_2",
    LARGE_FLAT_RATE_BOX = "LARGE_FLAT_RATE_BOX"
}
/** @enumType */
type PackageTypeWithLiterals = PackageType | 'UNKNOWN_PACKAGE_TYPE' | 'CUSTOM' | 'FLAT_RATE_ENVELOPE' | 'PADDED_FLAT_RATE_ENVELOPE' | 'SMALL_FLAT_RATE_BOX' | 'MEDIUM_FLAT_RATE_BOX_1' | 'MEDIUM_FLAT_RATE_BOX_2' | 'LARGE_FLAT_RATE_BOX';
interface PackageDetails {
    /**
     * Package name. Must be set when package type is CUSTOM.
     * For other package types, it is read-only, and an exception will be thrown
     * if it set when creating a ShippoConfiguration.
     * @maxLength 255
     */
    name?: string | null;
    /**
     * Package dimensions. Can only be set when package type is CUSTOM.
     * For other package types, it is read-only, and an exception will be thrown
     * if it set when creating a ShippoConfiguration.
     */
    dimensions?: PackageDimensions;
    /**
     * Maximum number of products. Must be set when package type is NOT CUSTOM.
     * Otherwise, if the package type is CUSTOM, this field cannot be set and an
     * exception will be thrown if it is set when creating a ShippoConfiguration.
     */
    maxNumberOfProducts?: string | null;
}
interface PackageDimensions {
    /**
     * Package length.
     * @decimalValue options { gte:0, maxScale:3 }
     */
    length?: string;
    /**
     * Package width.
     * @decimalValue options { gte:0, maxScale:3 }
     */
    width?: string;
    /**
     * Package height.
     * @decimalValue options { gte:0, maxScale:3 }
     */
    height?: string;
}
/** Physical address */
interface Address {
    /**
     * Two-letter country code in [ISO-3166 alpha-2](https://www.iso.org/obp/ui/#search/code/) format.
     * @format COUNTRY
     */
    country?: string | null;
    /**
     * Code for a subdivision (such as state, prefecture, or province) in [ISO 3166-2](https://www.iso.org/standard/72483.html) format.
     * @maxLength 50
     */
    subdivision?: string | null;
    /**
     * City name.
     * @maxLength 50
     */
    city?: string | null;
    /**
     * Postal or zip code.
     * @maxLength 50
     */
    postalCode?: string | null;
    /** Street address. */
    streetAddress?: StreetAddress;
    /**
     * Main address line (usually street name and number).
     * @maxLength 150
     */
    addressLine1?: string | null;
    /**
     * Free text providing more detailed address info. Usually contains apt, suite, floor.
     * @maxLength 100
     */
    addressLine2?: string | null;
    /**
     * Country's full name.
     * @readonly
     */
    countryFullname?: string | null;
    /**
     * Subdivision full-name.
     * @readonly
     */
    subdivisionFullname?: string | null;
}
interface StreetAddress {
    /** Street number. */
    number?: string;
    /** Street name. */
    name?: string;
}
interface AddressLocation {
    /** Address latitude. */
    latitude?: number | null;
    /** Address longitude. */
    longitude?: number | null;
}
interface ExtendedFields {
    /**
     * Extended field data. Each key corresponds to the namespace of the app that created the extended fields.
     * The value of each key is structured according to the schema defined when the extended fields were configured.
     *
     * You can only access fields for which you have the appropriate permissions.
     *
     * Learn more about [extended fields](https://dev.wix.com/docs/rest/articles/getting-started/extended-fields).
     */
    namespaces?: Record<string, Record<string, any>>;
}
interface CreateShippoConfigurationRequest {
    /** ShippoConfiguration to be created. */
    shippoConfiguration: ShippoConfiguration;
    /** @decimalValue options { gte:0, maxScale:6 } */
    backupRate?: string | null;
}
interface CreateShippoConfigurationResponse {
    /** The created ShippoConfiguration. */
    shippoConfiguration?: ShippoConfiguration;
}
interface GetShippoConfigurationRequest {
    /**
     * ID of the ShippoConfiguration to retrieve.
     * @format GUID
     */
    shippoConfigurationId: string;
}
interface GetShippoConfigurationResponse {
    /** The requested ShippoConfiguration. */
    shippoConfiguration?: ShippoConfiguration;
}
interface UpdateShippoConfigurationRequest {
    /** ShippoConfiguration to be updated, may be partial. */
    shippoConfiguration: ShippoConfiguration;
}
interface UpdateShippoConfigurationResponse {
    /** Updated ShippoConfiguration. */
    shippoConfiguration?: ShippoConfiguration;
}
interface DeleteShippoConfigurationRequest {
    /**
     * ID of the ShippoConfiguration to delete.
     * @format GUID
     */
    shippoConfigurationId: string;
}
interface DeleteShippoConfigurationResponse {
}
interface QueryShippoConfigurationsRequest {
    /** WQL expression. */
    query?: CursorQuery;
}
interface CursorQuery extends CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * Example of operators: `$eq`, `$ne`, `$lt`, `$lte`, `$gt`, `$gte`, `$in`, `$hasSome`, `$hasAll`, `$startsWith`, `$contains`
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     * @maxSize 5
     */
    sort?: Sorting[];
}
/** @oneof */
interface CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface QueryShippoConfigurationsResponse {
    /** List of ShippoConfigurations. */
    shippoConfigurations?: ShippoConfiguration[];
    /** Paging metadata. */
    pagingMetadata?: CursorPagingMetadata;
}
interface CursorPagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Cursor strings that point to the next page, previous page, or both. */
    cursors?: Cursors;
    /**
     * Whether there are more pages to retrieve following the current page.
     *
     * + `true`: Another page of results can be retrieved.
     * + `false`: This is the last page.
     */
    hasNext?: boolean | null;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface UpdateExtendedFieldsRequest {
    /** ID of the entity to update. */
    _id: string;
    /** Identifier for the app whose extended fields are being updated. */
    namespace: string;
    /** Data to update. Structured according to the [schema](https://dev.wix.com/docs/rest/articles/getting-started/extended-fields#json-schema-for-extended-fields) defined when the extended fields were configured. */
    namespaceData: Record<string, any> | null;
}
interface UpdateExtendedFieldsResponse {
    /** Updated ShippoConfiguration. */
    shippoConfiguration?: ShippoConfiguration;
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface Empty {
}
interface AddDeliveryRegionRequest {
    /**
     * ID of the ShippoConfiguration to add the delivery region to.
     * @format GUID
     */
    shippoConfigurationId: string;
    /**
     * ID of the delivery region to add.
     * @format GUID
     */
    deliveryRegionId: string;
    /** Revision of the ShippoConfiguration. */
    revision?: string | null;
}
interface AddDeliveryRegionResponse {
    /** The updated ShippoConfiguration. */
    shippoConfiguration?: ShippoConfiguration;
}
interface RemoveDeliveryRegionRequest {
    /**
     * ID of the ShippoConfiguration to remove the delivery region from.
     * @format GUID
     */
    shippoConfigurationId: string;
    /**
     * ID of the delivery region to remove.
     * @format GUID
     */
    deliveryRegionId: string;
    /** Revision of the ShippoConfiguration. */
    revision?: string | null;
}
interface RemoveDeliveryRegionResponse {
    /** The updated ShippoConfiguration, or empty if the ShippoConfiguration was deleted. */
    shippoConfiguration?: ShippoConfiguration;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface ShippoConfigurationCreatedEnvelope {
    entity: ShippoConfiguration;
    metadata: EventMetadata;
}
interface ShippoConfigurationDeletedEnvelope {
    entity: ShippoConfiguration;
    metadata: EventMetadata;
}
interface ShippoConfigurationUpdatedEnvelope {
    entity: ShippoConfiguration;
    metadata: EventMetadata;
}
interface CreateShippoConfigurationOptions {
    /** @decimalValue options { gte:0, maxScale:6 } */
    backupRate?: string | null;
}
interface UpdateShippoConfiguration {
    /**
     * ShippoConfiguration ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /** @readonly */
    revision?: string | null;
    /**
     * Date and time the ShippoConfiguration was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the ShippoConfiguration was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Associated delivery region ID.
     * @format GUID
     * @immutable
     * @deprecated Associated delivery region ID.
     * @replacedBy delivery_region_ids
     * @targetRemovalDate 2025-06-01
     */
    deliveryRegionId?: string | null;
    /**
     * Settings of USPS domestic services.
     * @maxSize 3
     */
    domesticServices?: DomesticServiceSettings[];
    /**
     * Settings of USPS international services.
     * @maxSize 3
     */
    internationalServices?: InternationalServiceSettings[];
    /** Package type. */
    packageType?: PackageTypeWithLiterals;
    /** Package details. */
    packageDetails?: PackageDetails;
    /**
     * Location ID from OS location service.
     * @format GUID
     */
    osLocationId?: string | null;
    /**
     * Ship from address materialized from OS location.
     * @readonly
     */
    shipFromAddress?: Address;
    /**
     * This shippo configuration is active for the following delivery regions.
     * @maxSize 50
     * @format GUID
     * @immutable
     */
    deliveryRegionIds?: string[];
    /**
     * Backup weight.
     * @decimalValue options { gte:0, maxScale:5 }
     */
    backupWeight?: string | null;
    /** Data extensions. */
    extendedFields?: ExtendedFields;
}
interface QueryCursorResult {
    cursors: Cursors;
    hasNext: () => boolean;
    hasPrev: () => boolean;
    length: number;
    pageSize: number;
}
interface ShippoConfigurationsQueryResult extends QueryCursorResult {
    items: ShippoConfiguration[];
    query: ShippoConfigurationsQueryBuilder;
    next: () => Promise<ShippoConfigurationsQueryResult>;
    prev: () => Promise<ShippoConfigurationsQueryResult>;
}
interface ShippoConfigurationsQueryBuilder {
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    eq: (propertyName: '_id' | 'deliveryRegionId', value: any) => ShippoConfigurationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    ne: (propertyName: '_id' | 'deliveryRegionId', value: any) => ShippoConfigurationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    ge: (propertyName: '_id' | 'deliveryRegionId', value: any) => ShippoConfigurationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    gt: (propertyName: '_id' | 'deliveryRegionId', value: any) => ShippoConfigurationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    le: (propertyName: '_id' | 'deliveryRegionId', value: any) => ShippoConfigurationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `value`.
     * @param value - Value to compare against.
     * @documentationMaturity preview
     */
    lt: (propertyName: '_id' | 'deliveryRegionId', value: any) => ShippoConfigurationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `string`.
     * @param string - String to compare against. Case-insensitive.
     * @documentationMaturity preview
     */
    startsWith: (propertyName: '_id' | 'deliveryRegionId', value: string) => ShippoConfigurationsQueryBuilder;
    /** @param propertyName - Property whose value is compared with `values`.
     * @param values - List of values to compare against.
     * @documentationMaturity preview
     */
    hasSome: (propertyName: '_id' | 'deliveryRegionId', value: any[]) => ShippoConfigurationsQueryBuilder;
    /** @documentationMaturity preview */
    in: (propertyName: '_id' | 'deliveryRegionId', value: any) => ShippoConfigurationsQueryBuilder;
    /** @documentationMaturity preview */
    exists: (propertyName: '_id' | 'deliveryRegionId', value: boolean) => ShippoConfigurationsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    ascending: (...propertyNames: Array<'_id' | 'deliveryRegionId'>) => ShippoConfigurationsQueryBuilder;
    /** @param propertyNames - Properties used in the sort. To sort by multiple properties, pass properties as additional arguments.
     * @documentationMaturity preview
     */
    descending: (...propertyNames: Array<'_id' | 'deliveryRegionId'>) => ShippoConfigurationsQueryBuilder;
    /** @param limit - Number of items to return, which is also the `pageSize` of the results object.
     * @documentationMaturity preview
     */
    limit: (limit: number) => ShippoConfigurationsQueryBuilder;
    /** @param cursor - A pointer to specific record
     * @documentationMaturity preview
     */
    skipTo: (cursor: string) => ShippoConfigurationsQueryBuilder;
    /** @documentationMaturity preview */
    find: () => Promise<ShippoConfigurationsQueryResult>;
}
interface UpdateExtendedFieldsOptions {
    /** Data to update. Structured according to the [schema](https://dev.wix.com/docs/rest/articles/getting-started/extended-fields#json-schema-for-extended-fields) defined when the extended fields were configured. */
    namespaceData: Record<string, any> | null;
}
interface AddDeliveryRegionOptions {
    /** Revision of the ShippoConfiguration. */
    revision?: string | null;
}
interface RemoveDeliveryRegionIdentifiers {
    /**
     * ID of the ShippoConfiguration to remove the delivery region from.
     * @format GUID
     */
    shippoConfigurationId: string;
    /**
     * ID of the delivery region to remove.
     * @format GUID
     */
    deliveryRegionId: string;
}
interface RemoveDeliveryRegionOptions {
    /** Revision of the ShippoConfiguration. */
    revision?: string | null;
}

export { type ActionEvent as $, type AddDeliveryRegionOptions as A, type CursorQuery as B, type CreateShippoConfigurationOptions as C, DomesticService as D, type ExtendedFields as E, type CursorQueryPagingMethodOneOf as F, type GetShippoConfigurationRequest as G, type HandlingFee as H, InternationalService as I, type Sorting as J, type CursorPaging as K, type QueryShippoConfigurationsResponse as L, type CursorPagingMetadata as M, type Cursors as N, type UpdateExtendedFieldsRequest as O, PackageType as P, type QueryShippoConfigurationsRequest as Q, type RemoveDeliveryRegionIdentifiers as R, type ShippoConfiguration as S, type DomainEvent as T, type UpdateShippoConfiguration as U, type DomainEventBodyOneOf as V, WebhookIdentityType as W, type EntityCreatedEvent as X, type RestoreInfo as Y, type EntityUpdatedEvent as Z, type EntityDeletedEvent as _, type ShippoConfigurationsQueryBuilder as a, type Empty as a0, type AddDeliveryRegionRequest as a1, type RemoveDeliveryRegionRequest as a2, type MessageEnvelope as a3, type IdentificationData as a4, type IdentificationDataIdOneOf as a5, type BaseEventMetadata as a6, type EventMetadata as a7, type ShippoConfigurationsQueryResult as a8, type UpdateExtendedFieldsOptions as b, type UpdateExtendedFieldsResponse as c, type AddDeliveryRegionResponse as d, type RemoveDeliveryRegionOptions as e, type RemoveDeliveryRegionResponse as f, type ShippoConfigurationCreatedEnvelope as g, type ShippoConfigurationDeletedEnvelope as h, type ShippoConfigurationUpdatedEnvelope as i, CalculationType as j, SortOrder as k, type DomesticServiceSettings as l, type ServiceSettings as m, type InternationalServiceSettings as n, type PackageDetails as o, type PackageDimensions as p, type Address as q, type StreetAddress as r, type AddressLocation as s, type CreateShippoConfigurationRequest as t, type CreateShippoConfigurationResponse as u, type GetShippoConfigurationResponse as v, type UpdateShippoConfigurationRequest as w, type UpdateShippoConfigurationResponse as x, type DeleteShippoConfigurationRequest as y, type DeleteShippoConfigurationResponse as z };
