import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { S as ShippoConfiguration, C as CreateShippoConfigurationOptions, U as UpdateShippoConfiguration, a as ShippoConfigurationsQueryBuilder, b as UpdateExtendedFieldsOptions, c as UpdateExtendedFieldsResponse, A as AddDeliveryRegionOptions, d as AddDeliveryRegionResponse, R as RemoveDeliveryRegionIdentifiers, e as RemoveDeliveryRegionOptions, f as RemoveDeliveryRegionResponse, g as ShippoConfigurationCreatedEnvelope, h as ShippoConfigurationDeletedEnvelope, i as ShippoConfigurationUpdatedEnvelope } from './ecom-v1-shippo-configuration-shippo-configurations.universal-D-nyXVmj.js';
export { $ as ActionEvent, a1 as AddDeliveryRegionRequest, q as Address, s as AddressLocation, a6 as BaseEventMetadata, j as CalculationType, t as CreateShippoConfigurationRequest, u as CreateShippoConfigurationResponse, K as CursorPaging, M as CursorPagingMetadata, B as CursorQuery, F as CursorQueryPagingMethodOneOf, N as Cursors, y as DeleteShippoConfigurationRequest, z as DeleteShippoConfigurationResponse, T as DomainEvent, V as DomainEventBodyOneOf, D as DomesticService, l as DomesticServiceSettings, a0 as Empty, X as EntityCreatedEvent, _ as EntityDeletedEvent, Z as EntityUpdatedEvent, a7 as EventMetadata, E as ExtendedFields, G as GetShippoConfigurationRequest, v as GetShippoConfigurationResponse, H as HandlingFee, a4 as IdentificationData, a5 as IdentificationDataIdOneOf, I as InternationalService, n as InternationalServiceSettings, a3 as MessageEnvelope, o as PackageDetails, p as PackageDimensions, P as PackageType, Q as QueryShippoConfigurationsRequest, L as QueryShippoConfigurationsResponse, a2 as RemoveDeliveryRegionRequest, Y as RestoreInfo, m as ServiceSettings, a8 as ShippoConfigurationsQueryResult, k as SortOrder, J as Sorting, r as StreetAddress, O as UpdateExtendedFieldsRequest, w as UpdateShippoConfigurationRequest, x as UpdateShippoConfigurationResponse, W as WebhookIdentityType } from './ecom-v1-shippo-configuration-shippo-configurations.universal-D-nyXVmj.js';

declare function createShippoConfiguration$1(httpClient: HttpClient): CreateShippoConfigurationSignature;
interface CreateShippoConfigurationSignature {
    /**
     * Creates a ShippoConfiguration.
     * @param - ShippoConfiguration to be created.
     * @returns The created ShippoConfiguration.
     */
    (shippoConfiguration: ShippoConfiguration, options?: CreateShippoConfigurationOptions | undefined): Promise<ShippoConfiguration>;
}
declare function getShippoConfiguration$1(httpClient: HttpClient): GetShippoConfigurationSignature;
interface GetShippoConfigurationSignature {
    /**
     * Retrieves a ShippoConfiguration.
     * @param - ID of the ShippoConfiguration to retrieve.
     * @returns The requested ShippoConfiguration.
     */
    (shippoConfigurationId: string): Promise<ShippoConfiguration>;
}
declare function updateShippoConfiguration$1(httpClient: HttpClient): UpdateShippoConfigurationSignature;
interface UpdateShippoConfigurationSignature {
    /**
     * Updates a ShippoConfiguration.
     * @param - ShippoConfiguration ID.
     * @returns Updated ShippoConfiguration.
     */
    (_id: string, shippoConfiguration: UpdateShippoConfiguration): Promise<ShippoConfiguration>;
}
declare function deleteShippoConfiguration$1(httpClient: HttpClient): DeleteShippoConfigurationSignature;
interface DeleteShippoConfigurationSignature {
    /**
     * Deletes a ShippoConfiguration.
     * @param - ID of the ShippoConfiguration to delete.
     */
    (shippoConfigurationId: string): Promise<void>;
}
declare function queryShippoConfigurations$1(httpClient: HttpClient): QueryShippoConfigurationsSignature;
interface QueryShippoConfigurationsSignature {
    /**
     * Retrieves a list of ShippoConfigurations, given the provided [paging, filtering, and sorting][1].
     *
     * Up to 1,000 ShippoConfigurations can be returned per request.
     *
     * To learn how to query ShippoConfigurations, see [API Query Language][2].
     *
     * [1]: https://dev.wix.com/api/rest/getting-started/sorting-and-paging
     * [2]: https://dev.wix.com/api/rest/getting-started/api-query-language
     */
    (): ShippoConfigurationsQueryBuilder;
}
declare function updateExtendedFields$1(httpClient: HttpClient): UpdateExtendedFieldsSignature;
interface UpdateExtendedFieldsSignature {
    /**
     * Updates extended fields of a ShippoConfiguration without incrementing revision
     * @param - ID of the entity to update.
     * @param - Identifier for the app whose extended fields are being updated.
     */
    (_id: string, namespace: string, options: UpdateExtendedFieldsOptions): Promise<UpdateExtendedFieldsResponse>;
}
declare function addDeliveryRegion$1(httpClient: HttpClient): AddDeliveryRegionSignature;
interface AddDeliveryRegionSignature {
    /**
     * Adds a delivery region to a Shippo configuration.
     * @param - ID of the ShippoConfiguration to add the delivery region to.
     * @param - ID of the delivery region to add.
     */
    (shippoConfigurationId: string, deliveryRegionId: string, options?: AddDeliveryRegionOptions | undefined): Promise<AddDeliveryRegionResponse>;
}
declare function removeDeliveryRegion$1(httpClient: HttpClient): RemoveDeliveryRegionSignature;
interface RemoveDeliveryRegionSignature {
    /**
     * Removes a delivery region from a Shippo configuration.
     * When passing the ID of the only existing delivery region, removing it will delete the Shippo configuration.
     */
    (identifiers: RemoveDeliveryRegionIdentifiers, options?: RemoveDeliveryRegionOptions | undefined): Promise<RemoveDeliveryRegionResponse>;
}
declare const onShippoConfigurationCreated$1: EventDefinition<ShippoConfigurationCreatedEnvelope, "wix.ecom.v1.shippo_configuration_created">;
declare const onShippoConfigurationDeleted$1: EventDefinition<ShippoConfigurationDeletedEnvelope, "wix.ecom.v1.shippo_configuration_deleted">;
declare const onShippoConfigurationUpdated$1: EventDefinition<ShippoConfigurationUpdatedEnvelope, "wix.ecom.v1.shippo_configuration_updated">;

declare const createShippoConfiguration: MaybeContext<BuildRESTFunction<typeof createShippoConfiguration$1> & typeof createShippoConfiguration$1>;
declare const getShippoConfiguration: MaybeContext<BuildRESTFunction<typeof getShippoConfiguration$1> & typeof getShippoConfiguration$1>;
declare const updateShippoConfiguration: MaybeContext<BuildRESTFunction<typeof updateShippoConfiguration$1> & typeof updateShippoConfiguration$1>;
declare const deleteShippoConfiguration: MaybeContext<BuildRESTFunction<typeof deleteShippoConfiguration$1> & typeof deleteShippoConfiguration$1>;
declare const queryShippoConfigurations: MaybeContext<BuildRESTFunction<typeof queryShippoConfigurations$1> & typeof queryShippoConfigurations$1>;
declare const updateExtendedFields: MaybeContext<BuildRESTFunction<typeof updateExtendedFields$1> & typeof updateExtendedFields$1>;
declare const addDeliveryRegion: MaybeContext<BuildRESTFunction<typeof addDeliveryRegion$1> & typeof addDeliveryRegion$1>;
declare const removeDeliveryRegion: MaybeContext<BuildRESTFunction<typeof removeDeliveryRegion$1> & typeof removeDeliveryRegion$1>;
/**
 * Triggered when a shipping option is created.
 */
declare const onShippoConfigurationCreated: BuildEventDefinition<typeof onShippoConfigurationCreated$1>;
/**
 * Triggered when a shipping option is deleted.
 */
declare const onShippoConfigurationDeleted: BuildEventDefinition<typeof onShippoConfigurationDeleted$1>;
/**
 * Triggered when a shipping option is updated.
 */
declare const onShippoConfigurationUpdated: BuildEventDefinition<typeof onShippoConfigurationUpdated$1>;

export { AddDeliveryRegionOptions, AddDeliveryRegionResponse, CreateShippoConfigurationOptions, RemoveDeliveryRegionIdentifiers, RemoveDeliveryRegionOptions, RemoveDeliveryRegionResponse, ShippoConfiguration, ShippoConfigurationCreatedEnvelope, ShippoConfigurationDeletedEnvelope, ShippoConfigurationUpdatedEnvelope, ShippoConfigurationsQueryBuilder, UpdateExtendedFieldsOptions, UpdateExtendedFieldsResponse, UpdateShippoConfiguration, addDeliveryRegion, createShippoConfiguration, deleteShippoConfiguration, getShippoConfiguration, onShippoConfigurationCreated, onShippoConfigurationDeleted, onShippoConfigurationUpdated, queryShippoConfigurations, removeDeliveryRegion, updateExtendedFields, updateShippoConfiguration };
